#! /bin/sh

# Test pmlcreate with the standard example input file

tstdir=`pwd`
tmpdir="/tmp/pmltest-$$"
tmpinp='tmp.txt'
mkdir -p $tmpdir
cd $tmpdir
$tstdir/../pmlcreate -e > $tmpinp
$tstdir/../pmlcreate $tmpinp
if [ "$1" = 's' ]; then
  $tstdir/../pmlvalid *.xml 1>/dev/null
else
  $tstdir/../pmlvalid *.xml 1>&2
fi
es=$?
rm $tmpinp *.xml
cd $tstdir
rmdir $tmpdir
exit $es
